# RolePermissionsResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**role** | [**RoleResponse**](RoleResponse.md) |  | 
**role_string** | **str** |  | 
**permissions** | [**list[PermissionResponse]**](PermissionResponse.md) |  | 
**permissions_string** | **list[str]** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

